@@ -93,7 +93,7 @@ class YesWeHack(YwhApiObject):
                     raise AccessDenied(json_resp.get("error_description", 'Authentication Failed'))
             if resp.status_code == 404:
                 raise ObjectNotFound
-            raise Exception("YWH error " + resp.text)
+            raise APIError("YWH error " + resp.text)
 
         return json_resp
 
