@@ -8,8 +8,8 @@ class APIError(Exception):
 class InvalidResponse(APIError):
     """ Non json response"""
 
-    def __init__(self):
-        super().__init__("Non json response")
+    def __init__(self, message=None):
+        super().__init__("Non json response" if not message else f"Non json response: {message}")
 
 
 class ObjectNotFound(APIError):
